Small query language for pseudorandomness
See https://github.com/Zheoni/rng-query for the syntax and CLI.
Usage as a lib
rng-query is mainly the CLI app, so this lib is not the main objective. I
will try to follow semver but for the lib it’s not a
guarantee, so you may want to pin a specific version.
Run a whole input with run_query or have more control with State and
its methods.
All Display implementations of the crate may output ANSI color codes.
Use something like anstream if you dont want
colors.
Structs
- A sample from a selected entry
- Query interpreter
Enums
- Query error
Functions
- Run a query